@@ -20,7 +20,7 @@ iteritems = (dict.iteritems if sys.version < 3
 
 from . import (core, target, antitarget, coverage, fix, metrics, reference,
                reports, export, importers, segmentation,
-               ngfrills, plots)
+               params, ngfrills, plots)
 from .ngfrills import echo
 from .cnarray import CopyNumArray as CNA
 
@@ -304,7 +304,9 @@ def do_targets(bed_fname, out_fname, annotate=None, do_short_names=False,
     # Output with logging
     with ngfrills.safe_write(out_fname, False) as outfile:
         i = 0
-        for i, row in enumerate(bed_rows):
+        for i, row in enumerate(sorted(bed_rows,
+                                       key=lambda r: (core.sorter_chrom(r[0]),
+                                                      r[1]))):
             outfile.write("\t".join(map(str, row)) + '\n')
         ngfrills.echo("Wrote", out_fname,
                       "with", i + 1, "target intervals")
@@ -346,9 +348,11 @@ def _cmd_antitarget(args):
         echo("Wrote", args.output, "with", i + 1, "background intervals")
 
 
-def do_antitarget(target_bed,
-                  access_bed=None, avg_bin_size=100000, min_bin_size=10000):
+def do_antitarget(target_bed, access_bed=None, avg_bin_size=150000,
+                  min_bin_size=None):
     """Derive a background/antitarget BED file from a target BED file."""
+    if not min_bin_size:
+        min_bin_size = 2 * int(avg_bin_size * (2 ** params.MIN_BIN_COVERAGE))
     background_regions = antitarget.get_background(target_bed, access_bed,
                                                    avg_bin_size, min_bin_size)
 
@@ -375,9 +379,9 @@ P_anti.add_argument('interval',
 P_anti.add_argument('-g', '--access',
         help="""Regions of accessible sequence on chromosomes (.bed), as
                 output by genome2access.py.""")
-P_anti.add_argument('-a', '--avg-size', type=int, default=100000,
+P_anti.add_argument('-a', '--avg-size', type=int, default=150000,
         help="Average size of antitarget bins (results are approximate).")
-P_anti.add_argument('-m', '--min-size', type=int, default=10000,
+P_anti.add_argument('-m', '--min-size', type=int,
         help="Minimum size of antitarget bins (smaller regions are dropped).")
 P_anti.add_argument('-o', '--output', help="""Output file name.""")
 P_anti.set_defaults(func=_cmd_antitarget)
@@ -1004,17 +1008,17 @@ def _cmd_breaks(args):
     """List the targeted genes in which a copy number breakpoint occurs."""
     pset_cvg = CNA.read(args.filename)
     pset_seg = CNA.read(args.segment)
-    bpoints = do_breaks(pset_cvg, pset_seg)
+    bpoints = do_breaks(pset_cvg, pset_seg, args.min_probes)
     echo("Found", len(bpoints), "gene breakpoints")
     core.write_tsv(args.output, bpoints,
                    colnames=['Gene', 'Chrom.', 'Location', 'Change',
                              'ProbesLeft', 'ProbesRight'])
 
 
-def do_breaks(probes, segments):
+def do_breaks(probes, segments, min_probes=1):
     """List the targeted genes in which a copy number breakpoint occurs."""
     intervals = reports.get_gene_intervals(probes)
-    bpoints = reports.get_breakpoints(intervals, segments)
+    bpoints = reports.get_breakpoints(intervals, segments, min_probes)
     return bpoints
 
 
@@ -1024,6 +1028,9 @@ P_breaks.add_argument('filename',
                 of the 'fix' sub-command.""")
 P_breaks.add_argument('segment',
         help="Segmentation calls (.cns), the output of the 'segment' command).")
+P_breaks.add_argument('-m', '--min-probes', type=int, default=1,
+        help="""Minimum number of within-gene probes on both sides of a
+                breakpoint to report it.""")
 P_breaks.add_argument('-o', '--output',
         help="Output table file name.")
 P_breaks.set_defaults(func=_cmd_breaks)
